@@ -1,8 +1,10 @@
 package App::GitGot::Command::mux;
-$App::GitGot::Command::mux::VERSION = '1.26'; # TRIAL
+$App::GitGot::Command::mux::VERSION = '1.27'; # TRIAL
 # ABSTRACT: open a tmux window for a selected project
 use 5.014;
 
+use IO::Prompt::Simple;
+
 use App::GitGot -command;
 
 use Moo;
@@ -15,17 +17,29 @@ sub options {
   my( $class , $app ) = @_;
   return (
     [ 'dirty|D'   => 'open session or window for all dirty repos' ] ,
+    [ 'exec|e=s'  => 'pass a command to the `tmux new-window` command (not valid in combination with -s option)'] ,
     [ 'session|s' => 'use tmux-sessions (default: tmux windows)' ] ,
   );
 }
 
+sub _use_io_page { 0 }
+
 sub _execute {
   my( $self, $opt, $args ) = @_;
 
+  die "-e and -s are mutually exclusive"
+    if $self->opt->exec and $self->opt->session;
+
   my @repos = $self->opt->dirty ? $self->_get_dirty_repos() : $self->active_repos();
 
   my $target = $self->opt->session ? 'session' : 'window';
 
+  if ( @repos >= 25 ) {
+    my $repo_count = scalar @repos;
+    return unless
+      prompt( "\nYou're about to open $repo_count ${target}s - you sure about that? ", { yn => 1, default => 'n' } );
+  }
+
  REPO: foreach my $repo ( @repos ) {
     # is it already opened?
     my %windows = reverse map { /^(\d+):::(\S+)/ }
@@ -48,7 +62,9 @@ sub _execute {
       system 'tmux', 'new-session', '-d', '-s', $repo->name;
       system 'tmux', 'switch-client', '-t' => $repo->name;}
     else {
-      system 'tmux', 'new-window', '-n', $repo->name;
+      my @args = (qw/ tmux new-window -n / , $repo->name );
+      push( @args , $self->opt->exec ) if $self->opt->exec;
+      system @args;
     }
   }
 }
@@ -87,7 +103,7 @@ App::GitGot::Command::mux - open a tmux window for a selected project
 
 =head1 VERSION
 
-version 1.26
+version 1.27
 
 =head1 AUTHOR
 
